pub struct PaginatedResponseUserFundingPayment {
pub data: Vec<PaginatedResponseUserFundingPaymentDataItem>,
pub next_cursor: Option<String>,
}Expand description
paginated response wrapper with optional cursor for next page
JSON schema
{
"description": "paginated response wrapper with optional cursor for next page",
"type": "object",
"required": [
"data"
],
"properties": {
"data": {
"type": "array",
"items": {
"description": "user funding payment history",
"type": "object",
"required": [
"eventNumber",
"fundingApplied",
"marketId",
"symbol",
"time",
"txHash"
],
"properties": {
"eventNumber": {
"type": "integer",
"format": "uint64",
"minimum": 0.0
},
"fundingApplied": {
"type": "string",
"format": "decimal"
},
"marketId": {
"type": "integer",
"format": "uint16",
"minimum": 0.0
},
"symbol": {
"type": "string"
},
"time": {
"type": "integer",
"format": "int64"
},
"txHash": {
"type": "string"
}
}
}
},
"nextCursor": {
"type": [
"string",
"null"
]
}
}
}Fields
data: Vec<PaginatedResponseUserFundingPaymentDataItem>next_cursor: Option<String>Trait Implementations
Sourceimpl Clone for PaginatedResponseUserFundingPayment
impl Clone for PaginatedResponseUserFundingPayment
Sourcefn clone(&self) -> PaginatedResponseUserFundingPayment
fn clone(&self) -> PaginatedResponseUserFundingPayment
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl<'de> Deserialize<'de> for PaginatedResponseUserFundingPayment
impl<'de> Deserialize<'de> for PaginatedResponseUserFundingPayment
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more