pub struct PaginatedResponseUserLiquidation {
pub data: Vec<PaginatedResponseUserLiquidationDataItem>,
pub next_cursor: Option<String>,
}Expand description
paginated response wrapper with optional cursor for next page
JSON schema
{
"description": "paginated response wrapper with optional cursor for next page",
"type": "object",
"required": [
"data"
],
"properties": {
"data": {
"type": "array",
"items": {
"type": "object",
"required": [
"eventNumber",
"liquidateeAddress",
"liquidatorAddress",
"liquidatorReward",
"markPrice",
"marketId",
"realizedPnl",
"side",
"size",
"symbol",
"time",
"txHash"
],
"properties": {
"eventNumber": {
"type": "integer",
"format": "uint64",
"minimum": 0.0
},
"liquidateeAddress": {
"type": "string"
},
"liquidatorAddress": {
"type": "string"
},
"liquidatorReward": {
"type": "string",
"format": "decimal"
},
"markPrice": {
"type": "string",
"format": "decimal"
},
"marketId": {
"type": "integer",
"format": "uint16",
"minimum": 0.0
},
"realizedPnl": {
"type": "string",
"format": "decimal"
},
"side": {
"type": "string"
},
"size": {
"type": "string",
"format": "decimal"
},
"symbol": {
"type": "string"
},
"time": {
"type": "integer",
"format": "int64"
},
"txHash": {
"type": "string"
}
}
}
},
"nextCursor": {
"type": [
"string",
"null"
]
}
}
}Fields
data: Vec<PaginatedResponseUserLiquidationDataItem>next_cursor: Option<String>Trait Implementations
Sourceimpl Clone for PaginatedResponseUserLiquidation
impl Clone for PaginatedResponseUserLiquidation
Sourcefn clone(&self) -> PaginatedResponseUserLiquidation
fn clone(&self) -> PaginatedResponseUserLiquidation
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl<'de> Deserialize<'de> for PaginatedResponseUserLiquidation
impl<'de> Deserialize<'de> for PaginatedResponseUserLiquidation
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more