pub struct PaginatedResponseUserTrade {
pub data: Vec<PaginatedResponseUserTradeDataItem>,
pub next_cursor: Option<String>,
}Expand description
paginated response wrapper with optional cursor for next page
JSON schema
{
"description": "paginated response wrapper with optional cursor for next page",
"type": "object",
"required": [
"data"
],
"properties": {
"data": {
"type": "array",
"items": {
"type": "object",
"required": [
"address",
"buyer",
"commission",
"commissionAsset",
"id",
"maker",
"orderId",
"positionSide",
"price",
"qty",
"quoteQty",
"realizedPnl",
"side",
"symbol",
"time",
"txHash"
],
"properties": {
"address": {
"type": "string"
},
"buyer": {
"type": "boolean"
},
"commission": {
"type": "string",
"format": "decimal"
},
"commissionAsset": {
"type": "string"
},
"id": {
"type": "integer",
"format": "uint64",
"minimum": 0.0
},
"maker": {
"type": "boolean"
},
"orderId": {
"type": "integer",
"format": "uint64",
"minimum": 0.0
},
"positionSide": {
"type": "string"
},
"price": {
"type": "string",
"format": "decimal"
},
"qty": {
"type": "string",
"format": "decimal"
},
"quoteQty": {
"type": "string",
"format": "decimal"
},
"realizedPnl": {
"type": "string",
"format": "decimal"
},
"side": {
"type": "string"
},
"symbol": {
"type": "string"
},
"time": {
"type": "integer",
"format": "int64"
},
"txHash": {
"type": "string"
}
}
}
},
"nextCursor": {
"type": [
"string",
"null"
]
}
}
}Fields
data: Vec<PaginatedResponseUserTradeDataItem>next_cursor: Option<String>Trait Implementations
Sourceimpl Clone for PaginatedResponseUserTrade
impl Clone for PaginatedResponseUserTrade
Sourcefn clone(&self) -> PaginatedResponseUserTrade
fn clone(&self) -> PaginatedResponseUserTrade
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for PaginatedResponseUserTrade
impl Debug for PaginatedResponseUserTrade
Sourceimpl<'de> Deserialize<'de> for PaginatedResponseUserTrade
impl<'de> Deserialize<'de> for PaginatedResponseUserTrade
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more