pub struct PaginatedResponseUserWithdrawal {
pub data: Vec<PaginatedResponseUserWithdrawalDataItem>,
pub next_cursor: Option<String>,
}Expand description
paginated response wrapper with optional cursor for next page
JSON schema
{
"description": "paginated response wrapper with optional cursor for next page",
"type": "object",
"required": [
"data"
],
"properties": {
"data": {
"type": "array",
"items": {
"type": "object",
"required": [
"amount",
"amountNotional",
"asset",
"assetId",
"eventNumber",
"fee",
"time",
"txHash"
],
"properties": {
"amount": {
"type": "string",
"format": "decimal"
},
"amountNotional": {
"type": "string",
"format": "decimal"
},
"asset": {
"type": "string"
},
"assetId": {
"type": "integer",
"format": "uint16",
"minimum": 0.0
},
"eventNumber": {
"type": "integer",
"format": "uint64",
"minimum": 0.0
},
"fee": {
"type": "string",
"format": "decimal"
},
"time": {
"type": "integer",
"format": "int64"
},
"txHash": {
"type": "string"
}
}
}
},
"nextCursor": {
"type": [
"string",
"null"
]
}
}
}Fields
data: Vec<PaginatedResponseUserWithdrawalDataItem>next_cursor: Option<String>Trait Implementations
Sourceimpl Clone for PaginatedResponseUserWithdrawal
impl Clone for PaginatedResponseUserWithdrawal
Sourcefn clone(&self) -> PaginatedResponseUserWithdrawal
fn clone(&self) -> PaginatedResponseUserWithdrawal
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl<'de> Deserialize<'de> for PaginatedResponseUserWithdrawal
impl<'de> Deserialize<'de> for PaginatedResponseUserWithdrawal
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more