pub struct NewTriggerOrderArgs {
pub side: Side,
pub order_price: PositiveDecimal,
pub trigger_price: PositiveDecimal,
pub trigger_direction: TriggerDirection,
pub price_condition: TriggerPriceCondition,
pub size: Option<PositiveDecimal>,
pub order_type: OrderType,
}Fields
side: Sideorder_price: PositiveDecimaltrigger_price: PositiveDecimaltrigger_direction: TriggerDirectionprice_condition: TriggerPriceConditionsize: Option<PositiveDecimal>order_type: OrderTypeTrait Implementations
Sourceimpl BorshDeserialize for NewTriggerOrderArgs
impl BorshDeserialize for NewTriggerOrderArgs
fn deserialize_reader<__R>(
reader: &mut __R,
) -> Result<NewTriggerOrderArgs, Error>where
__R: Read,
Sourcefn deserialize(buf: &mut &[u8]) -> Result<Self, Error>
fn deserialize(buf: &mut &[u8]) -> Result<Self, Error>
Deserializes this instance from a given slice of bytes.
Updates the buffer to point at the remaining bytes.
Sourcefn try_from_slice(v: &[u8]) -> Result<Self, Error>
fn try_from_slice(v: &[u8]) -> Result<Self, Error>
Deserialize this instance from a slice of bytes.
fn try_from_reader<R>(reader: &mut R) -> Result<Self, Error>where
R: Read,
Sourceimpl BorshSerialize for NewTriggerOrderArgs
impl BorshSerialize for NewTriggerOrderArgs
Sourceimpl Clone for NewTriggerOrderArgs
impl Clone for NewTriggerOrderArgs
Sourcefn clone(&self) -> NewTriggerOrderArgs
fn clone(&self) -> NewTriggerOrderArgs
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for NewTriggerOrderArgs
impl Debug for NewTriggerOrderArgs
Sourceimpl<'de> Deserialize<'de> for NewTriggerOrderArgs
impl<'de> Deserialize<'de> for NewTriggerOrderArgs
Sourcefn deserialize<__D>(
__deserializer: __D,
) -> Result<NewTriggerOrderArgs, <__D as Deserializer<'de>>::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(
__deserializer: __D,
) -> Result<NewTriggerOrderArgs, <__D as Deserializer<'de>>::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl Hash for NewTriggerOrderArgs
impl Hash for NewTriggerOrderArgs
Sourceimpl JsonSchema for NewTriggerOrderArgs
impl JsonSchema for NewTriggerOrderArgs
Sourcefn schema_name() -> String
fn schema_name() -> String
The name of the generated JSON Schema. Read more
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn is_referenceable() -> bool
fn is_referenceable() -> bool
Whether JSON Schemas generated for this type should be re-used where possible using the
$ref keyword. Read moreSourceimpl Ord for NewTriggerOrderArgs
impl Ord for NewTriggerOrderArgs
Sourcefn cmp(&self, other: &NewTriggerOrderArgs) -> Ordering
fn cmp(&self, other: &NewTriggerOrderArgs) -> Ordering
1.21.0 · Sourcefn max(self, other: Self) -> Selfwhere
Self: Sized,
fn max(self, other: Self) -> Selfwhere
Self: Sized,
Compares and returns the maximum of two values. Read more
Sourceimpl PartialEq for NewTriggerOrderArgs
impl PartialEq for NewTriggerOrderArgs
Sourceimpl PartialOrd for NewTriggerOrderArgs
impl PartialOrd for NewTriggerOrderArgs
Sourceimpl Serialize for NewTriggerOrderArgs
impl Serialize for NewTriggerOrderArgs
Sourcefn serialize<__S>(
&self,
__serializer: __S,
) -> Result<<__S as Serializer>::Ok, <__S as Serializer>::Error>where
__S: Serializer,
fn serialize<__S>(
&self,
__serializer: __S,
) -> Result<<__S as Serializer>::Ok, <__S as Serializer>::Error>where
__S: Serializer,
Serialize this value into the given Serde serializer. Read more
Sourceimpl UniversalWallet for NewTriggerOrderArgs
impl UniversalWallet for NewTriggerOrderArgs
Sourcefn scaffold() -> Item<IndexLinking>
fn scaffold() -> Item<IndexLinking>
Generate the “scaffolding” of the item. If the item is a primtive, this is just the corresponding primtive.
If the type is composed of other types, this is the container with all links set to
Link::Placeholder.Sourcefn get_child_links(schema: &mut Schema) -> Vec<Link>
fn get_child_links(schema: &mut Schema) -> Vec<Link>
Ensure that each type contained in the outer type (i.e. the type of each struct/tuple field) is added to the schema,
and return a
Link connecting the child to the parent. Read moreSourcefn get_child_templates(schema: &mut Schema) -> TransactionTemplateSet
fn get_child_templates(schema: &mut Schema) -> TransactionTemplateSet
Empty by default
When derived by the macro, builds a template set from annotations on the fields + the field
types’ own get_child_templates()
Sourcefn write_schema(schema: &mut Schema) -> Link
fn write_schema(schema: &mut Schema) -> Link
Writes the type to the schema if it is not already present and returns a link to it. Read more
Sourcefn make_root_of(schema: &mut Schema)
fn make_root_of(schema: &mut Schema)
Writes the type and all its children to the schema, if not already present, and sets the
type as a root type. Generates any templates defined on that type.
Sourcefn make_linkable(schema: &mut Schema) -> Link
fn make_linkable(schema: &mut Schema) -> Link
Gets a link to the type, writing the type to the schema if necessary.
Sourcefn id_override() -> Option<ItemId>
fn id_override() -> Option<ItemId>
Override the type ID of the item. This should typically not be written by hand. Instead,
use the
OverrideSchema trait.impl Eq for NewTriggerOrderArgs
impl StructuralPartialEq for NewTriggerOrderArgs