pub enum WsEvent {
Message(Box<ServerMessage>),
Reconnecting,
Disconnected(String),
}Expand description
Events delivered to the user from the managed WebSocket.
Variants
Message(Box<ServerMessage>)
A message from the server.
Reconnecting
The connection was lost and a reconnect is in progress. Subscriptions will be replayed automatically.
Disconnected(String)
The connection was permanently lost after exhausting retries.