SDKError

Enum SDKError 

#[non_exhaustive]
pub enum SDKError {
Show 20 variants InvalidNetwork, InvalidPrivateKey(String), JsonSerializeError(Error), HttpError(Error), ApiError(ApiErrorResponse), RequestError(String), MissingKeypair, StringParseError(FromUtf8Error), ChainIdCastError(TryFromIntError), InvalidNetworkUrl, InvalidSchemaResponse(&'static str), InvalidChainHash(String), SerializationError(String), SystemTimeError, InvalidSignatureLength(usize), InvalidPublicKeyLength(usize), SchemaOutdated, UnsupportedCallMessage(String), TransactionOutdated, WebsocketError(Box<WSErrors>),
}
Errors that can occur when using the Trading SDK.

Variants (Non-exhaustive)

This enum is marked as non-exhaustive
Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.


InvalidNetwork

Invalid network configuration.



InvalidPrivateKey(String)

Invalid private key format or length.



JsonSerializeError(Error)

JSON serialization error.



HttpError(Error)

HTTP client error.



ApiError(ApiErrorResponse)

Structured API error from the trading API.



RequestError(String)

Client-side request error (not from the server).



MissingKeypair

No keypair available for signing.



StringParseError(FromUtf8Error)



ChainIdCastError(TryFromIntError)



InvalidNetworkUrl



InvalidSchemaResponse(&'static str)



InvalidChainHash(String)



SerializationError(String)



SystemTimeError



InvalidSignatureLength(usize)



InvalidPublicKeyLength(usize)



SchemaOutdated



UnsupportedCallMessage(String)



TransactionOutdated



WebsocketError(Box<WSErrors>)

Implementations

Source

impl SDKError

pub fn is_retryable(&self) -> bool

Whether this error is potentially transient and the operation could be retried with backoff.

pub fn api_error(&self) -> Option<&ApiErrorResponse>

If this is an API error, returns the structured response.