pub struct PositiveDecimal(/* private fields */);Expand description
A decimal value that must be positive. Wraps rust_decimal::Decimal.
ⓘ
use rust_decimal::Decimal;
use bullet_rust_sdk::PositiveDecimal;
let price = PositiveDecimal::try_from(Decimal::from(50000))?;
let qty = PositiveDecimal::try_from(Decimal::new(1, 3))?; // 0.001Implementations
Sourceimpl PositiveDecimal
impl PositiveDecimal
Sourcepub const ZERO: PositiveDecimal
pub const ZERO: PositiveDecimal
The smallest positive value that can be represented by PositiveDecimal.
pub const ONE: PositiveDecimal
pub const TWO: PositiveDecimal
pub const TEN: PositiveDecimal
pub const ONE_HUNDRED: PositiveDecimal
pub const MAX: PositiveDecimal
pub fn new(value: Decimal) -> Option<PositiveDecimal>
pub fn to_fixed(&self, rounding_mode: RoundingMode) -> FixedPositiveDecimal
pub fn as_dec(&self) -> Decimal
pub fn is_zero(&self) -> bool
pub fn fract(&self) -> Decimal
pub fn try_pow_i64(&self, v: i64) -> Result<PositiveDecimal, ArithmeticError>
pub fn try_with_precision( &self, precision: i64, ) -> Result<PositiveDecimal, ArithmeticError>
Sourcepub fn saturating_sub(self, v: impl Into<Decimal>) -> PositiveDecimal
pub fn saturating_sub(self, v: impl Into<Decimal>) -> PositiveDecimal
Performs a saturating subtraction for PositiveDecimal, this is for intentional saturating subtractions hence no warnings We don’t return a result because we know the saturating subtraction result will always be non-negative